@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 
 # This program is free software; you can redistribute it and/or
@@ -98,4 +97,16 @@ class MainWin(gtk.Window):
     def BackToMain(self, widget):
         self.SetPage(self.MainPage)
 
+    def RefreshPage(self, updatedPlugin):
+        currentPage = self.CurrentPage
+
+        if isinstance(currentPage, PluginPage) and currentPage.Plugin:
+            for basePlugin in updatedPlugin.GetExtensionBasePlugins ():
+                # If updatedPlugin is an extension plugin and a base plugin
+                # is currently being displayed, then update its current page
+                if currentPage.Plugin.Name == basePlugin.Name:
+                    if currentPage.CheckDialogs(basePlugin, self):
+                        currentPage.RefreshPage(basePlugin, self)
+                    break
+
 gtk.window_set_default_icon_name('ccsm')
